pub struct IrqMutexGuard<'g, T> {
mutex: &'g IrqMutex<T>,
rflags: RFlags,
}Expand description
RAII guard for IrqMutex; releases the lock and restores the interrupt flag on drop.
Fields
mutex: &'g IrqMutex<T>rflags: RFlagsRFLAGS captured before interrupts were disabled; its IF bit decides whether to re-enable on drop.
Implementations
Sourceimpl<'g, T> IrqMutexGuard<'g, T>
impl<'g, T> IrqMutexGuard<'g, T>
Sourcepub fn new(mutex: &'g IrqMutex<T>, rflags: RFlags) -> IrqMutexGuard<'g, T>
pub fn new(mutex: &'g IrqMutex<T>, rflags: RFlags) -> IrqMutexGuard<'g, T>
Construct a guard associated with mutex, saving rflags for later restore.